"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAccount = exports.getCreateAccountInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getCreateAccountInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u32()],
        ['lamports', (0, umi_1.mapAmountSerializer)(s.u64(), 'SOL', 9)],
        ['space', s.u64()],
        ['programId', s.publicKey()],
    ], { description: 'CreateAccountInstructionData' }), (value) => ({ ...value, discriminator: 0 }));
}
exports.getCreateAccountInstructionDataSerializer = getCreateAccountInstructionDataSerializer;
function createAccount(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('splSystem', '11111111111111111111111111111111');
    const payerAccount = input.payer ?? context.payer;
    const newAccountAccount = input.newAccount;
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    signers.push(newAccountAccount);
    keys.push({
        pubkey: newAccountAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newAccountAccount, true),
    });
    const data = getCreateAccountInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = Number(input.space) + umi_1.ACCOUNT_HEADER_SIZE;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.createAccount = createAccount;
//# sourceMappingURL=createAccount.js.map